@@ -1,7 +1,13 @@
 from PySide6.QtCore import QSize
 from PySide6.QtGui import QPainter
-from PySide6.QtWidgets import QProxyStyle, QTabBar, QStyle, QStyleOption, QWidget, QStyleOptionTab
-
+from PySide6.QtWidgets import (
+    QProxyStyle,
+    QStyle,
+    QStyleOption,
+    QStyleOptionTab,
+    QTabBar,
+    QWidget,
+)
 
 # NOTE: possible styling conflicts
 #
@@ -10,15 +16,26 @@ from PySide6.QtWidgets import QProxyStyle, QTabBar, QStyle, QStyleOption, QWidge
 
 
 class RareStyle(QProxyStyle):
-
-    def sizeFromContents(self, types: QStyle.ContentsType, option: QStyleOption, size: QSize, widget: QWidget) -> QSize:
+    def sizeFromContents(
+        self,
+        types: QStyle.ContentsType,
+        option: QStyleOption,
+        size: QSize,
+        widget: QWidget,
+    ) -> QSize:
         size = super(RareStyle, self).sizeFromContents(types, option, size, widget)
         if types == QStyle.ContentsType.CT_TabBarTab:
             if option.shape in {QTabBar.Shape.RoundedEast, QTabBar.Shape.RoundedWest}:
                 size.transpose()
         return size
 
-    def drawControl(self, element: QStyle.ControlElement, option: QStyleOption, painter: QPainter, widget: QWidget) -> None:
+    def drawControl(
+        self,
+        element: QStyle.ControlElement,
+        option: QStyleOption,
+        painter: QPainter,
+        widget: QWidget,
+    ) -> None:
         if element == QStyle.ControlElement.CE_TabBarTabLabel:
             if option.shape in {QTabBar.Shape.RoundedEast, QTabBar.Shape.RoundedWest}:
                 opt = QStyleOptionTab(option)
